#!/bin/sh
#
# usage: run-hostap.sh <interface> <ssid>
#

if [ $# -lt 2 ]; then
    echo "usage: $0 <interface> <ssid>"
    exit 1
fi

TOPDIR=`dirname $0`/..
DHCPCONF=$TOPDIR/etc/dhcpd.conf
DHCPLEAS=$TOPDIR/etc/dhcpd.leases
INTERFACE=$1
SSID=$2

if [ ! -f $TOPDIR/etc/dhcpd.conf ]; then
    echo "$TOPDIR/etc/dhcpd.conf: File not found"
    exit 1
fi

if [ ! -f $DHCPLEAS ]; then
    touch $DHCPLEAS
fi

hostap_start()
{
    echo "Starting HostAP..."

    if [ "$OSTYPE" = "FreeBSD" ]; then
        ifconfig $INTERFACE down
        ifconfig $INTERFACE -mediaopt monitor
        ifconfig $INTERFACE inet 10.13.37.254 netmask 255.255.255.0 channel 4 ssid "$SSID" mediaopt hostap up
    else
        echo "Linux support broken right now"
        exit 1
        iwconfig wlan0 channel 1 # ...
        ifconfig wlan0 inet 10.13.37.254 up
    fi
}

hostap_stop()
{
    echo "Stopping HostAP..."

    if [ "$OSTYPE" = "FreeBSD" ]; then
	ifconfig $INTERFACE down
        ifconfig $INTERFACE inet 10.13.37.254 delete -mediaopt hostap ssid ""
        exit 1
    else
        echo "Linux support broken right now"
	exit 1
    fi
}

trap hostap_stop INT

hostap_start

# Start Service Manager
$TOPDIR/src/servicemanager.rb 10.13.37.254 &

# Start DHCP
dhcpd -d -f -cf $DHCPCONF -lf $DHCPLEAS $1
